package MARC::Field008::L10N::en;

use base qw(MARC::Field008::L10N);
use strict;
use warnings;

our $VERSION = 0.01;

our %Lexicon = (
	'_AUTO' => 1,

	# Type of date.
	'type_of_date.b' => 'No dates given; B.C. date involved',
	'type_of_date.c' => 'Continuing resource currently published',
	'type_of_date.d' => 'Continuing resource ceased publication',
	'type_of_date.e' => 'Detailed date',
	'type_of_date.i' => 'Inclusive dates of collection',
	'type_of_date.k' => 'Range of years of bulk of collection',
	'type_of_date.m' => 'Multiple dates',
	'type_of_date.n' => 'Dates unknown',
	'type_of_date.p' => 'Date of distribution/release/issue and production/recording session when different',
	'type_of_date.q' => 'Questionable date',
	'type_of_date.r' => 'Reprint/reissue date and original date',
	'type_of_date.s' => 'Single known date/probable date',
	'type_of_date.t' => 'Publication date and copyright date',
	'type_of_date.u' => 'Continuing resource status unknown',
	'type_of_date.|' => 'No attempt to code',

	# Modified record.
	'modified_record._' => 'Not modified',
	'modified_record.d' => 'Dashed-on information omitted',
	'modified_record.o' => 'Completely romanized/printed cards romanized',
	'modified_record.r' => 'Completely romanized/printed cards in script',
	'modified_record.s' => 'Shortened',
	'modified_record.x' => 'Missing characters',
	'modified_record.|' => 'No attempt to code',

	# Cataloging source.
	'cataloging_source._' => 'National bibliographic agency',
	'cataloging_source.c' => 'Cooperative cataloging program',
	'cataloging_source.d' => 'Other',
	'cataloging_source.u' => 'Unknown',
	'cataloging_source.|' => 'No attempt to code',

	# common material - Target audience.
	'target_audience._' => 'Unknown or not specified',
	'target_audience.a' => 'Preschool',
	'target_audience.b' => 'Primary',
	'target_audience.c' => 'Pre-adolescent',
	'target_audience.d' => 'Adolescent',
	'target_audience.e' => 'Adult',
	'target_audience.f' => 'Specialized',
	'target_audience.g' => 'General',
	'target_audience.j' => 'Juvenile',
	'target_audience.|' => 'No attempt to code',

	# common material - Government publication.
	'government_publication._' => 'Not a government publication',
	'government_publication.a' => 'Autonomous or semi-autonomous component',
	'government_publication.c' => 'Multilocal',
	'government_publication.f' => 'Federal/national',
	'government_publication.i' => 'International intergovernmental',
	'government_publication.l' => 'Local',
	'government_publication.m' => 'Multistate',
	'government_publication.o' => 'Government publication-level undetermined',
	'government_publication.s' => 'State, provincial, territorial, dependent, etc.',
	'government_publication.u' => 'Unknown if item is government publication',
	'government_publication.z' => 'Other',
	'government_publication.|' => 'No attempt to code',

	# book, map, music, continuing resources, visual material, mixed materials - Form of item.
	'form_of_item._' => 'None of the following',
	'form_of_item.a' => 'Microfilm',
	'form_of_item.b' => 'Microfiche',
	'form_of_item.c' => 'Microopaque',
	'form_of_item.d' => 'Large print',
	'form_of_item.f' => 'Braille',
	'form_of_item.o' => 'Online',
	'form_of_item.q' => 'Direct electronic',
	'form_of_item.r' => 'Regular print reproduction',
	'form_of_item.s' => 'Electronic',
	'form_of_item.|' => 'No attempt to code',

	# book, map - Index.
	'index.0' => 'No index',
	'index.1' => 'Index present',
	'index.|' => 'No attempt to code',

	# book, continuing_resources - Conference publication.
	'conference_publication.0' => 'Not a conference publication',
	'conference_publication.1' => 'Conference publication',
	'conference_publication.|' => 'No attempt to code',

	# book, continuing_resources - Nature of contents.
	'nature_of_content._' => 'No specified nature of contents',
	'nature_of_content.a' => 'Abstracts/summaries',
	'nature_of_content.b' => 'Bibliographies',
	'nature_of_content.c' => 'Catalogs',
	'nature_of_content.d' => 'Dictionaries',
	'nature_of_content.e' => 'Encyclopedias',
	'nature_of_content.f' => 'Handbooks',
	'nature_of_content.g' => 'Legal articles',
	'nature_of_content.i' => 'Indexes',
	'nature_of_content.j' => 'Patent document',
	'nature_of_content.k' => 'Discographies',
	'nature_of_content.l' => 'Legislation',
	'nature_of_content.m' => 'Theses',
	'nature_of_content.n' => 'Surveys of literature in a subject area',
	'nature_of_content.o' => 'Reviews',
	'nature_of_content.p' => 'Programmed texts',
	'nature_of_content.q' => 'Filmographies',
	'nature_of_content.r' => 'Directories',
	'nature_of_content.s' => 'Statistics',
	'nature_of_content.t' => 'Technical reports',
	'nature_of_content.u' => 'Standards/specifications',
	'nature_of_content.v' => 'Legal cases and case notes',
	'nature_of_content.w' => 'Law reports and digests',
	'nature_of_content.y' => 'Yearbooks',
	'nature_of_content.z' => 'Treaties',
	'nature_of_content.2' => 'Offprints',
	'nature_of_content.5' => 'Calendars',
	'nature_of_content.6' => 'Comics/graphic novels',
	'nature_of_content.|' => 'No attempt to code',

	# book - Illustrations.
	'book.illustrations._' => 'No illustrations',
	'book.illustrations.a' => 'Illustrations',
	'book.illustrations.b' => 'Maps',
	'book.illustrations.c' => 'Portraits',
	'book.illustrations.d' => 'Charts',
	'book.illustrations.e' => 'Plans',
	'book.illustrations.f' => 'Plates',
	'book.illustrations.g' => 'Music',
	'book.illustrations.h' => 'Facsimiles',
	'book.illustrations.i' => 'Coats of arms',
	'book.illustrations.j' => 'Genealogical tables',
	'book.illustrations.k' => 'Forms',
	'book.illustrations.l' => 'Samples',
	'book.illustrations.m' => 'Phonodisc, phonowire, etc.',
	'book.illustrations.o' => 'Photographs',
	'book.illustrations.p' => 'Illuminations',
	'book.illustrations.|' => 'No attempt to code',

	# book - Festschrift.
	'book.festschrift.0' => 'Not a festschrift',
	'book.festschrift.1' => 'Festschrift',
	'book.festschrift.|' => 'No attempt to code',

	# book - Literary form.
	'book.literary_form.0' => 'Not fiction (not further specified)',
	'book.literary_form.1' => 'Fiction (not further specified)',
	'book.literary_form.d' => 'Dramas',
	'book.literary_form.e' => 'Essays',
	'book.literary_form.f' => 'Novels',
	'book.literary_form.h' => 'Humor, satires, etc.',
	'book.literary_form.i' => 'Letters',
	'book.literary_form.j' => 'Short stories',
	'book.literary_form.m' => 'Mixed forms',
	'book.literary_form.p' => 'Poetry',
	'book.literary_form.s' => 'Speeches',
	'book.literary_form.u' => 'Unknown',
	'book.literary_form.|' => 'No attempt to code',

	# book - Biography.
	'book.biography._' => 'No biographical material',
	'book.biography.a' => 'Autobiography',
	'book.biography.b' => 'Individual biography',
	'book.biography.c' => 'Collective biography',
	'book.biography.d' => 'Contains biographical information',
	'book.biography.|' => 'No attempt to code',

	# computer_file - Form of item.
	'computer_file.form_of_item._' => 'Unknown or not specified',
	'computer_file.form_of_item.o' => 'Online',
	'computer_file.form_of_item.q' => 'Direct electronic',
	'computer_file.form_of_item.|' => 'No attempt to code',

	# computer_file - Type of computer file.
	'computer_file.type_of_computer_file.a' => 'Numeric data',
	'computer_file.type_of_computer_file.b' => 'Computer program',
	'computer_file.type_of_computer_file.c' => 'Representational',
	'computer_file.type_of_computer_file.d' => 'Document',
	'computer_file.type_of_computer_file.e' => 'Bibliographic data',
	'computer_file.type_of_computer_file.f' => 'Font',
	'computer_file.type_of_computer_file.g' => 'Game',
	'computer_file.type_of_computer_file.h' => 'Sound',
	'computer_file.type_of_computer_file.i' => 'Interactive multimedia',
	'computer_file.type_of_computer_file.j' => 'Online system or service',
	'computer_file.type_of_computer_file.m' => 'Combination',
	'computer_file.type_of_computer_file.u' => 'Unknown',
	'computer_file.type_of_computer_file.z' => 'Other',
	'computer_file.type_of_computer_file.|' => 'No attempt to code',

	# map - Relief.
	'map.relief._' => 'No relief shown',
	'map.relief.a' => 'Contours',
	'map.relief.b' => 'Shading',
	'map.relief.c' => 'Gradient and bathymetric tints',
	'map.relief.d' => 'Hachures',
	'map.relief.e' => 'Bathymetry/soundings',
	'map.relief.f' => 'Form lines',
	'map.relief.g' => 'Spot heights',
	'map.relief.i' => 'Pictorially',
	'map.relief.j' => 'Land forms',
	'map.relief.k' => 'Bathymetry/isolines',
	'map.relief.m' => 'Rock drawings',
	'map.relief.z' => 'Other',
	'map.relief.|' => 'No attempt to code',

	# map - Projection.
	'map.projection.__' => 'Projection not specified',
	'map.projection.aa' => 'Aitoff',
	'map.projection.ab' => 'Gnomic',
	'map.projection.ac' => 'Lambert\'s azimuthal equal area',
	'map.projection.ad' => 'Orthographic',
	'map.projection.ae' => 'Azimuthal equidistant',
	'map.projection.af' => 'Stereographic',
	'map.projection.ag' => 'General vertical near-sided',
	'map.projection.am' => 'Modified stereographic for Alaska',
	'map.projection.an' => 'Chamberlin trimetric',
	'map.projection.ap' => 'Polar stereographic',
	'map.projection.au' => 'Azimuthal, specific type unknown',
	'map.projection.az' => 'Azimuthal, other',
	'map.projection.ba' => 'Gall',
	'map.projection.bb' => 'Goode\'s homolographic',
	'map.projection.bc' => 'Lambert\'s cylindrical equal area',
	'map.projection.bd' => 'Mercator',
	'map.projection.be' => 'Miller',
	'map.projection.bf' => 'Mollweide',
	'map.projection.bg' => 'Sinusoidal',
	'map.projection.bh' => 'Transverse Mercator',
	'map.projection.bi' => 'Gauss-Kruger',
	'map.projection.bj' => 'Equirectangular',
	'map.projection.bk' => 'Krovak',
	'map.projection.bl' => 'Cassini-Soldner',
	'map.projection.bo' => 'Oblique Mercator',
	'map.projection.br' => 'Robinson',
	'map.projection.bs' => 'Space oblique Mercator',
	'map.projection.bu' => 'Cylindrical, specific type unknown',
	'map.projection.bz' => 'Cylindrical, other',
	'map.projection.ca' => 'Albers equal area',
	'map.projection.cb' => 'Bonne',
	'map.projection.cc' => 'Lambert\'s conformal conic',
	'map.projection.ce' => 'Equidistant conic',
	'map.projection.cp' => 'Polyconic',
	'map.projection.cu' => 'Conic, specific type unknown',
	'map.projection.cz' => 'Conic, other',
	'map.projection.da' => 'Armadillo',
	'map.projection.db' => 'Butterfly',
	'map.projection.dc' => 'Eckert',
	'map.projection.dd' => 'Goode\'s homolosine',
	'map.projection.de' => 'Miller\'s bipolar oblique conformal conic',
	'map.projection.df' => 'Van Der Grinten',
	'map.projection.dg' => 'Dimaxion',
	'map.projection.dh' => 'Cordiform',
	'map.projection.dl' => 'Lambert conformal',
	'map.projection.zz' => 'Other',
	'map.projection.||' => 'No attempt to code',

	# map - Type of cartographic material.
	'map.type_of_cartographic_material.a' => 'Single map',
	'map.type_of_cartographic_material.b' => 'Map series',
	'map.type_of_cartographic_material.c' => 'Map serial',
	'map.type_of_cartographic_material.d' => 'Globe',
	'map.type_of_cartographic_material.e' => 'Atlas',
	'map.type_of_cartographic_material.f' => 'Separate supplement to another work',
	'map.type_of_cartographic_material.g' => 'Bound as part of another work',
	'map.type_of_cartographic_material.r' => 'Remote sensing image',
	'map.type_of_cartographic_material.u' => 'Unknown',
	'map.type_of_cartographic_material.z' => 'Other',
	'map.type_of_cartographic_material.|' => 'No attempt to code',

	# map - Special format characteristics.
	'map.special_format_characteristics._' => 'No specified special format characteristics',
	'map.special_format_characteristics.e' => 'Manuscript',
	'map.special_format_characteristics.j' => 'Picture card, post card',
	'map.special_format_characteristics.k' => 'Calendar',
	'map.special_format_characteristics.l' => 'Puzzle',
	'map.special_format_characteristics.n' => 'Game',
	'map.special_format_characteristics.o' => 'Wall map',
	'map.special_format_characteristics.p' => 'Playing cards',
	'map.special_format_characteristics.r' => 'Loose-leaf',
	'map.special_format_characteristics.z' => 'Other',
	'map.special_format_characteristics.|' => 'No attempt to code',

	# music - Form of composition.
	'music.form_of_composition.an' => 'Anthems',
	'music.form_of_composition.bd' => 'Ballads',
	'music.form_of_composition.bg' => 'Bluegrass music',
	'music.form_of_composition.bl' => 'Blues',
	'music.form_of_composition.bt' => 'Ballets',
	'music.form_of_composition.ca' => 'Chaconnes',
	'music.form_of_composition.cb' => 'Chants, Other religions',
	'music.form_of_composition.cc' => 'Chant, Christian',
	'music.form_of_composition.cg' => 'Concerti grossi',
	'music.form_of_composition.ch' => 'Chorales',
	'music.form_of_composition.cl' => 'Chorale preludes',
	'music.form_of_composition.cn' => 'Canons and rounds',
	'music.form_of_composition.co' => 'Concertos',
	'music.form_of_composition.cp' => 'Chansons, polyphonic',
	'music.form_of_composition.cr' => 'Carols',
	'music.form_of_composition.cs' => 'Chance compositions',
	'music.form_of_composition.ct' => 'Cantatas',
	'music.form_of_composition.cy' => 'Country music',
	'music.form_of_composition.cz' => 'Canzonas',
	'music.form_of_composition.df' => 'Dance forms',
	'music.form_of_composition.dv' => 'Divertimentos, serenades, cassations, divertissements, and notturni',
	'music.form_of_composition.fg' => 'Fugues',
	'music.form_of_composition.fl' => 'Flamenco',
	'music.form_of_composition.fm' => 'Folk music',
	'music.form_of_composition.ft' => 'Fantasias',
	'music.form_of_composition.gm' => 'Gospel music',
	'music.form_of_composition.hy' => 'Hymns',
	'music.form_of_composition.jz' => 'Jazz',
	'music.form_of_composition.mc' => 'Musical revues and comedies',
	'music.form_of_composition.md' => 'Madrigals',
	'music.form_of_composition.mi' => 'Minuets',
	'music.form_of_composition.mo' => 'Motets',
	'music.form_of_composition.mp' => 'Motion picture music',
	'music.form_of_composition.mr' => 'Marches',
	'music.form_of_composition.ms' => 'Masses',
	'music.form_of_composition.mu' => 'Multiple forms',
	'music.form_of_composition.mz' => 'Mazurkas',
	'music.form_of_composition.nc' => 'Nocturnes',
	'music.form_of_composition.nn' => 'Not applicable',
	'music.form_of_composition.op' => 'Operas',
	'music.form_of_composition.or' => 'Oratorios',
	'music.form_of_composition.ov' => 'Overtures',
	'music.form_of_composition.pg' => 'Program music',
	'music.form_of_composition.pm' => 'Passion music',
	'music.form_of_composition.po' => 'Polonaises',
	'music.form_of_composition.pp' => 'Popular music',
	'music.form_of_composition.pr' => 'Preludes',
	'music.form_of_composition.ps' => 'Passacaglias',
	'music.form_of_composition.pt' => 'Part-songs',
	'music.form_of_composition.pv' => 'Pavans',
	'music.form_of_composition.rc' => 'Rock music',
	'music.form_of_composition.rd' => 'Rondos',
	'music.form_of_composition.rg' => 'Ragtime music',
	'music.form_of_composition.ri' => 'Ricercars',
	'music.form_of_composition.rp' => 'Rhapsodies',
	'music.form_of_composition.rq' => 'Requiems',
	'music.form_of_composition.sd' => 'Square dance music',
	'music.form_of_composition.sg' => 'Songs',
	'music.form_of_composition.sn' => 'Sonatas',
	'music.form_of_composition.sp' => 'Symphonic poems',
	'music.form_of_composition.st' => 'Studies and exercises',
	'music.form_of_composition.su' => 'Suites',
	'music.form_of_composition.sy' => 'Symphonies',
	'music.form_of_composition.tc' => 'Toccatas',
	'music.form_of_composition.tl' => 'Teatro lirico',
	'music.form_of_composition.ts' => 'Trio-sonatas',
	'music.form_of_composition.uu' => 'Unknown',
	'music.form_of_composition.vi' => 'Villancicos',
	'music.form_of_composition.vr' => 'Variations',
	'music.form_of_composition.wz' => 'Waltzes',
	'music.form_of_composition.za' => 'Zarzuelas',
	'music.form_of_composition.za' => 'Other',
	'music.form_of_composition.||' => 'No attempt to code',

	# music - Format of music.
	'music.format_of_music.a' => 'Full score',
	'music.format_of_music.b' => 'Miniature or study score',
	'music.format_of_music.c' => 'Accompaniment reduced for keyboard',
	'music.format_of_music.d' => 'Voice score with accompaniment omitted',
	'music.format_of_music.e' => 'Condensed score or piano-conductor score',
	'music.format_of_music.g' => 'Close score',
	'music.format_of_music.h' => 'Chorus score',
	'music.format_of_music.i' => 'Condensed score',
	'music.format_of_music.j' => 'Performer-conductor part',
	'music.format_of_music.k' => 'Vocal score',
	'music.format_of_music.l' => 'Score',
	'music.format_of_music.m' => 'Multiple score formats',
	'music.format_of_music.n' => 'Not applicable',
	'music.format_of_music.p' => 'Piano score',
	'music.format_of_music.u' => 'Unknown',
	'music.format_of_music.z' => 'Other',
	'music.format_of_music.|' => 'No attempt to code',

	# music - Music parts.
	'music.music_parts._' => 'No parts in hand or not specified',
	'music.music_parts.d' => 'Instrumental and vocal parts',
	'music.music_parts.e' => 'Instrumental parts',
	'music.music_parts.f' => 'Vocal parts',
	'music.music_parts.n' => 'Not applicable',
	'music.music_parts.u' => 'Unknown',
	'music.music_parts.|' => 'No attempt to code',

	# music - Accompanying matter.
	'music.accompanying_matter._' => 'No accompanying matter',
	'music.accompanying_matter.a' => 'Discography',
	'music.accompanying_matter.b' => 'Bibliography',
	'music.accompanying_matter.c' => 'Thematic index',
	'music.accompanying_matter.d' => 'Libretto or text',
	'music.accompanying_matter.e' => 'Biography of composer or author',
	'music.accompanying_matter.f' => 'Biography of performer or history of ensemble',
	'music.accompanying_matter.g' => 'Technical and/or historical information on instruments',
	'music.accompanying_matter.h' => 'Technical information on music',
	'music.accompanying_matter.i' => 'Historical information',
	'music.accompanying_matter.k' => 'Ethnological information',
	'music.accompanying_matter.r' => 'Instructional materials',
	'music.accompanying_matter.s' => 'Music',
	'music.accompanying_matter.z' => 'Other',
	'music.accompanying_matter.|' => 'No attempt to code',

	# music - Literary text for sound recordings.
	'music.literary_text_for_sound_recordings._' => 'Item is a music sound recording',
	'music.literary_text_for_sound_recordings.a' => 'Autobiography',
	'music.literary_text_for_sound_recordings.b' => 'Biography',
	'music.literary_text_for_sound_recordings.c' => 'Conference proceedings',
	'music.literary_text_for_sound_recordings.d' => 'Drama',
	'music.literary_text_for_sound_recordings.e' => 'Essays',
	'music.literary_text_for_sound_recordings.f' => 'Fiction',
	'music.literary_text_for_sound_recordings.g' => 'Reporting',
	'music.literary_text_for_sound_recordings.h' => 'History',
	'music.literary_text_for_sound_recordings.i' => 'Instruction',
	'music.literary_text_for_sound_recordings.j' => 'Language instruction',
	'music.literary_text_for_sound_recordings.k' => 'Comedy',
	'music.literary_text_for_sound_recordings.l' => 'Lectures, speeches',
	'music.literary_text_for_sound_recordings.m' => 'Memoirs',
	'music.literary_text_for_sound_recordings.n' => 'Not applicable',
	'music.literary_text_for_sound_recordings.o' => 'Folktales',
	'music.literary_text_for_sound_recordings.p' => 'Poetry',
	'music.literary_text_for_sound_recordings.r' => 'Rehearsals',
	'music.literary_text_for_sound_recordings.s' => 'Sounds',
	'music.literary_text_for_sound_recordings.t' => 'Interviews',
	'music.literary_text_for_sound_recordings.z' => 'Other',
	'music.literary_text_for_sound_recordings.|' => 'No attempt to code',

	# music - Transposition and arrangement.
	'music.transposition_and_arrangement._' => 'Not arrangement or transposition or not specified',
	'music.transposition_and_arrangement.a' => 'Transposition',
	'music.transposition_and_arrangement.b' => 'Arrangement',
	'music.transposition_and_arrangement.c' => 'Both transposed and arranged',
	'music.transposition_and_arrangement.n' => 'Not applicable',
	'music.transposition_and_arrangement.u' => 'Unknown',
	'music.transposition_and_arrangement.|' => 'No attempt to code',

	# continuing_resources - Frequency.
	'continuing_resource.frequency._' => 'No determinable frequency',
	'continuing_resource.frequency.a' => 'Annual',
	'continuing_resource.frequency.b' => 'Bimonthly',
	'continuing_resource.frequency.c' => 'Semiweekly',
	'continuing_resource.frequency.d' => 'Daily',
	'continuing_resource.frequency.e' => 'Biweekly',
	'continuing_resource.frequency.f' => 'Semiannual',
	'continuing_resource.frequency.g' => 'Biennial',
	'continuing_resource.frequency.h' => 'Triennial',
	'continuing_resource.frequency.i' => 'Three times a week',
	'continuing_resource.frequency.j' => 'Three times a month',
	'continuing_resource.frequency.k' => 'Continuously updated',
	'continuing_resource.frequency.m' => 'Monthly',
	'continuing_resource.frequency.q' => 'Quarterly',
	'continuing_resource.frequency.s' => 'Semimonthly',
	'continuing_resource.frequency.t' => 'Three times a year',
	'continuing_resource.frequency.u' => 'Unknown',
	'continuing_resource.frequency.w' => 'Weekly',
	'continuing_resource.frequency.z' => 'Other',
	'continuing_resource.frequency.|' => 'No attempt to code',

	# continuing_resources - Regularity.
	'continuing_resource.regularity.n' => 'Normalized irregular',
	'continuing_resource.regularity.r' => 'Regular',
	'continuing_resource.regularity.u' => 'Unknown',
	'continuing_resource.regularity.x' => 'Completely irregular',
	'continuing_resource.regularity.|' => 'No attempt to code',

	# continuing_resources - Type of continuing resource.
	'continuing_resources.type_of_continuing_resource._' => 'None of the following',
	'continuing_resources.type_of_continuing_resource.d' => 'Updating database',
	'continuing_resources.type_of_continuing_resource.g' => 'Magazine',
	'continuing_resources.type_of_continuing_resource.h' => 'Blog',
	'continuing_resources.type_of_continuing_resource.j' => 'Journal',
	'continuing_resources.type_of_continuing_resource.l' => 'Updating loose-leaf',
	'continuing_resources.type_of_continuing_resource.m' => 'Monographic series',
	'continuing_resources.type_of_continuing_resource.n' => 'Newspaper',
	'continuing_resources.type_of_continuing_resource.p' => 'Periodical',
	'continuing_resources.type_of_continuing_resource.r' => 'Repository',
	'continuing_resources.type_of_continuing_resource.s' => 'Newsletter',
	'continuing_resources.type_of_continuing_resource.t' => 'Directory',
	'continuing_resources.type_of_continuing_resource.w' => 'Updating Web site',
	'continuing_resources.type_of_continuing_resource.|' => 'No attempt to code',

	# continuing_resources - Form of original item.
	'continuing_resource.form_of_original_item._' => 'None of the following',
	'continuing_resource.form_of_original_item.a' => 'Microfilm',
	'continuing_resource.form_of_original_item.b' => 'Microfiche',
	'continuing_resource.form_of_original_item.c' => 'Microopaque',
	'continuing_resource.form_of_original_item.d' => 'Large print',
	'continuing_resource.form_of_original_item.e' => 'Newspaper format',
	'continuing_resource.form_of_original_item.f' => 'Braille',
	'continuing_resource.form_of_original_item.o' => 'Online',
	'continuing_resource.form_of_original_item.q' => 'Direct electronic',
	'continuing_resource.form_of_original_item.s' => 'Electronic',
	'continuing_resource.form_of_original_item.|' => 'No attempt to code',

	# continuing_resources - Nature of entire work.
	'continuing_resource.nature_of_entire_work._' => 'Not specified',
	'continuing_resource.nature_of_entire_work.a' => 'Abstracts/summaries',
	'continuing_resource.nature_of_entire_work.b' => 'Bibliographies',
	'continuing_resource.nature_of_entire_work.c' => 'Catalogs',
	'continuing_resource.nature_of_entire_work.d' => 'Dictionaries',
	'continuing_resource.nature_of_entire_work.e' => 'Encyclopedias',
	'continuing_resource.nature_of_entire_work.f' => 'Handbooks',
	'continuing_resource.nature_of_entire_work.g' => 'Legal articles',
	'continuing_resource.nature_of_entire_work.h' => 'Biography',
	'continuing_resource.nature_of_entire_work.i' => 'Indexes',
	'continuing_resource.nature_of_entire_work.k' => 'Discographies',
	'continuing_resource.nature_of_entire_work.l' => 'Legislation',
	'continuing_resource.nature_of_entire_work.m' => 'Theses',
	'continuing_resource.nature_of_entire_work.n' => 'Surveys of literature in a subject area',
	'continuing_resource.nature_of_entire_work.o' => 'Reviews',
	'continuing_resource.nature_of_entire_work.p' => 'Programmed texts',
	'continuing_resource.nature_of_entire_work.q' => 'Filmographies',
	'continuing_resource.nature_of_entire_work.r' => 'Directories',
	'continuing_resource.nature_of_entire_work.s' => 'Statistics',
	'continuing_resource.nature_of_entire_work.t' => 'Technical reports',
	'continuing_resource.nature_of_entire_work.u' => 'Standards/specifications',
	'continuing_resource.nature_of_entire_work.v' => 'Legal cases and case notes',
	'continuing_resource.nature_of_entire_work.w' => 'Law reports and digests',
	'continuing_resource.nature_of_entire_work.y' => 'Yearbooks',
	'continuing_resource.nature_of_entire_work.z' => 'Treaties',
	'continuing_resource.nature_of_entire_work.5' => 'Calendars',
	'continuing_resource.nature_of_entire_work.6' => 'Comics/graphic novels',
	'continuing_resource.nature_of_entire_work.|' => 'No attempt to code',

	# continuing_resources - Original alphabet or script of title.
	'continuing_resource.original_alphabet_or_script_of_title._' => 'No alphabet or script given/No key title',
	'continuing_resource.original_alphabet_or_script_of_title.a' => 'Basic Roman',
	'continuing_resource.original_alphabet_or_script_of_title.b' => 'Extended Roman',
	'continuing_resource.original_alphabet_or_script_of_title.c' => 'Cyrillic',
	'continuing_resource.original_alphabet_or_script_of_title.d' => 'Japanese',
	'continuing_resource.original_alphabet_or_script_of_title.e' => 'Chinese',
	'continuing_resource.original_alphabet_or_script_of_title.f' => 'Arabic',
	'continuing_resource.original_alphabet_or_script_of_title.g' => 'Greek',
	'continuing_resource.original_alphabet_or_script_of_title.h' => 'Hebrew',
	'continuing_resource.original_alphabet_or_script_of_title.i' => 'Thai',
	'continuing_resource.original_alphabet_or_script_of_title.j' => 'Devanagari',
	'continuing_resource.original_alphabet_or_script_of_title.k' => 'Korean',
	'continuing_resource.original_alphabet_or_script_of_title.l' => 'Tamil',
	'continuing_resource.original_alphabet_or_script_of_title.u' => 'Unknown',
	'continuing_resource.original_alphabet_or_script_of_title.z' => 'Other',
	'continuing_resource.original_alphabet_or_script_of_title.|' => 'No attempt to code',

	# continuing_resources - Entry convention.
	'continuing_resources.entry_convention.0' => 'Successive entry',
	'continuing_resources.entry_convention.1' => 'Latest entry',
	'continuing_resources.entry_convention.2' => 'Integrated entry',
	'continuing_resources.entry_convention.|' => 'No attempt to code',

	# visual_material - Running time for motion pictures and videorecordings.
	'visual_material.running_time_for_motion_pictures_and_videorecordings.000' => 'Running time exceeds three characters',
	'visual_material.running_time_for_motion_pictures_and_videorecordings.001' => 'Running time',
	'visual_material.running_time_for_motion_pictures_and_videorecordings.nnn' => 'Not applicable',
	'visual_material.running_time_for_motion_pictures_and_videorecordings.---' => 'Unknown',
	'visual_material.running_time_for_motion_pictures_and_videorecordings.|||' => 'No attempt to code',

	# visual_material - Type of visual material.
	'visual_material.type_of_visual_material.a' => 'Art original',
	'visual_material.type_of_visual_material.b' => 'Kit',
	'visual_material.type_of_visual_material.c' => 'Art reproduction',
	'visual_material.type_of_visual_material.d' => 'Diorama',
	'visual_material.type_of_visual_material.f' => 'Filmstrip',
	'visual_material.type_of_visual_material.g' => 'Game',
	'visual_material.type_of_visual_material.i' => 'Picture',
	'visual_material.type_of_visual_material.k' => 'Graphic',
	'visual_material.type_of_visual_material.l' => 'Technical drawing',
	'visual_material.type_of_visual_material.m' => 'Motion picture',
	'visual_material.type_of_visual_material.n' => 'Chart',
	'visual_material.type_of_visual_material.o' => 'Flash card',
	'visual_material.type_of_visual_material.p' => 'Microscope slide',
	'visual_material.type_of_visual_material.q' => 'Model',
	'visual_material.type_of_visual_material.r' => 'Realia',
	'visual_material.type_of_visual_material.s' => 'Slide',
	'visual_material.type_of_visual_material.t' => 'Transparency',
	'visual_material.type_of_visual_material.v' => 'Videorecording',
	'visual_material.type_of_visual_material.w' => 'Toy',
	'visual_material.type_of_visual_material.z' => 'Other',
	'visual_material.type_of_visual_material.|' => 'No attempt to code',

	# visual_material - Technique.
	'visual_material.technique.a' => 'Animation',
	'visual_material.technique.c' => 'Animation and live action',
	'visual_material.technique.l' => 'Live action',
	'visual_material.technique.n' => 'Not applicable',
	'visual_material.technique.u' => 'Unknown',
	'visual_material.technique.z' => 'Other',
	'visual_material.technique.|' => 'No attempt to code',
);

1;

__END__
